.. highlight:: shell

============
Installation
============

The installation will be available on PYPI.


For Equinor
-----------

For all Equinor users  `fmu-tools` will be installed through
Komodo, with access to stable, testing and bleeding versions.


For developers
--------------

See the Contributing documentation
